@@ -129,7 +129,6 @@ class Match(PyotCore):
 class MatchHistory(PyotCore):
     ids: List[str]
     puuid: str
-    _matches: List[Match]
 
     class Meta(PyotCore.Meta):
         rules = {"match_v1_matchlist": ["puuid"]}
@@ -145,7 +144,7 @@ class MatchHistory(PyotCore):
         return iter(self.matches)
 
     def __len__(self):
-        return len(self.matches)
+        return len(self.ids)
 
     def __init__(self, puuid: str = None, region: str = None):
         self._lazy_set(locals())
@@ -157,10 +156,7 @@ class MatchHistory(PyotCore):
 
     @property
     def matches(self) -> List[Match]:
-        if hasattr(self, "_matches"):
-            return self._matches
-        self._matches = [Match(id=id_, region=self.region) for id_ in self.ids]
-        return self._matches
+        return [Match(id=id_, region=self.region) for id_ in self.ids]
 
     @property
     def summoner(self) -> "Summoner":
