@@ -24,7 +24,7 @@ class ProfileIcon(PyotCore):
         if self.locale.lower() == "en_us":
             self._meta.server = "default"
         load = getattr(self._meta, "load")
-        load.pop("id")
+        self._meta.filter_key = str(load.pop("id"))
 
     def _transform(self, data):
         data["iconPath"] = tft_url(data["iconPath"])
